@@ -29,7 +29,7 @@
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
-#define QGIS_QML_SUBDIR "qml"
+#define QGIS_QML_SUBDIR "lib/qt/qml"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
